package net.knarcraft.ffmpegconverter.converter.module.output;

import net.knarcraft.ffmpegconverter.container.FFMpegCommand;
import net.knarcraft.ffmpegconverter.converter.module.ConverterModule;
import net.knarcraft.ffmpegconverter.streams.AudioStream;
import net.knarcraft.ffmpegconverter.streams.StreamObject;
import org.jetbrains.annotations.NotNull;

import java.util.List;

/**
 * A module for making FFMpeg copy the audio codec
 */
public class CopyAudioModule implements ConverterModule {

    private final List<AudioStream> streams;

    /**
     * Instantiates a new copy audio module
     *
     * @param streams <p>The streams to specify the copy flag for, or null to not use a per-stream selector</p>
     */
    public CopyAudioModule(@NotNull List<AudioStream> streams) {
        this.streams = streams;
    }

    /**
     * Instantiates a new copy audio module
     *
     * @param stream <p>The stream to specify the copy flag for</p>
     */
    public CopyAudioModule(@NotNull AudioStream stream) {
        this.streams = List.of(stream);
    }

    /**
     * Instantiates a new copy audio module
     */
    public CopyAudioModule() {
        this.streams = null;
    }

    @Override
    public void addArguments(@NotNull FFMpegCommand command) {
        if (this.streams != null) {
            for (StreamObject streamObject : this.streams) {
                int outputIndex = streamObject.getOutputIndex();
                if (outputIndex != -1) {
                    command.addOutputFileOption("-c:a:" + outputIndex, "copy");
                }
            }
        } else {
            command.addOutputFileOption("-c:a", "copy");
        }
    }

}
