package net.knarcraft.ffmpegconverter.streams;

import org.jetbrains.annotations.NotNull;

/**
 * An object describing a generic video file stream
 */
@SuppressWarnings("unused")
public interface StreamObject {

    /**
     * Gets the name of the stream codec
     *
     * @return <p>Codec name.</p>
     */
    @NotNull
    String getCodecName();

    /**
     * Gets the absolute index of a stream object
     *
     * @return <p>Absolute index.</p>
     */
    int getAbsoluteIndex();

    /**
     * Gets the index of the input file this stream belongs to
     *
     * <p>This is the first number given to a map argument in order to map this stream to the output file.</p>
     *
     * @return <p>The input index of this stream</p>
     */
    int getInputIndex();

    /**
     * Gets the relative index of a stream object (kth element of codec type)
     *
     * @return <p>Relative index.</p>
     */
    int getRelativeIndex();

    /**
     * Gets the language of the audio or subtitle stream
     *
     * @return <p>The language of the audio or subtitle stream.</p>
     */
    @NotNull
    String getLanguage();

    /**
     * Gets whether this stream is marked as the default stream of its type
     *
     * @return <p>True if this stream is marked as default</p>
     */
    boolean isDefault();

    /**
     * Gets the title of the subtitle stream
     *
     * @return <p>The title of the subtitle stream.</p>
     */
    @NotNull
    String getTitle();

    /**
     * Gets the character ffmpeg uses for this type of stream
     *
     * @return <p>The character used to specify this type of stream</p>
     */
    char streamTypeCharacter();

    /**
     * Gets the index of this stream in the output file
     *
     * @return <p>The index of this stream in the output file, or -1 if not set</p>
     */
    int getOutputIndex();

    /**
     * Sets the index of this stream in the output file
     *
     * <p>After sorting and selecting streams, setting the output index makes it much easier to set properties for this
     * specific stream, without having to rely on loops</p>
     *
     * @param newIndex <p>The new output index</p>
     */
    void setOutputIndex(int newIndex);

}
